package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertReisAppl;

public interface IBisTtsaCertReisApplService {
    BisTtsaCertReisAppl selectBisTtsaCertReisApplByGuid(String guid);
    List<BisTtsaCertReisAppl> selectBisTtsaCertReisApplList(BisTtsaCertReisAppl bisTtsaCertReisAppl);
    int insertBisTtsaCertReisAppl(BisTtsaCertReisAppl bisTtsaCertReisAppl);
    int updateBisTtsaCertReisAppl(BisTtsaCertReisAppl bisTtsaCertReisAppl);
    int deleteBisTtsaCertReisApplByGuid(String guid);
    int deleteBisTtsaCertReisApplByGuids(String[] guids);
}
