package com.goldenwater.slaj.ttsa.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertReisAppl;
import com.goldenwater.slaj.ttsa.service.IBisTtsaCertReisApplService;

@RestController
@RequestMapping("/ttsa/ttsacertreisappl")
public class BisTtsaCertReisApplController extends BaseController {
    @Autowired
    private IBisTtsaCertReisApplService bisTtsaCertReisApplService;

    @GetMapping("/list")
    public TableDataInfo list(BisTtsaCertReisAppl bisTtsaCertReisAppl) {
        startPage();
        List<BisTtsaCertReisAppl> list = bisTtsaCertReisApplService.selectBisTtsaCertReisApplList(bisTtsaCertReisAppl);
        return getDataTable(list);
    }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) {
        return AjaxResult.success(bisTtsaCertReisApplService.selectBisTtsaCertReisApplByGuid(guid));
    }

    @PostMapping
    public AjaxResult add(@RequestBody BisTtsaCertReisAppl bisTtsaCertReisAppl) {
        return toAjax(bisTtsaCertReisApplService.insertBisTtsaCertReisAppl(bisTtsaCertReisAppl));
    }

    @PutMapping
    public AjaxResult edit(@RequestBody BisTtsaCertReisAppl bisTtsaCertReisAppl) {
        return toAjax(bisTtsaCertReisApplService.updateBisTtsaCertReisAppl(bisTtsaCertReisAppl));
    }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) {
        return toAjax(bisTtsaCertReisApplService.deleteBisTtsaCertReisApplByGuids(guids));
    }

    @Log(title = "补发申请管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('ttsa:ttsacertreisappl:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BisTtsaCertReisAppl bisTtsaCertReisAppl) {
        List<BisTtsaCertReisAppl> list = bisTtsaCertReisApplService.selectBisTtsaCertReisApplList(bisTtsaCertReisAppl);
        ExcelUtil<BisTtsaCertReisAppl> util = new ExcelUtil<BisTtsaCertReisAppl>(BisTtsaCertReisAppl.class);
        util.exportExcel(response, list, "补发申请管理数据");
    }
}
